@@ -1,13 +1,21 @@
 from tickerdax.constants import KeyTypes
 from tickerdax.config_base import ConfigBase
+from tickerdax.formatting import truncate_datetime
 
 
 class Downloader(ConfigBase):
     """
     Downloads data from the https://tickerdax.com data api using a provided config.
     """
-    def __init__(self, config, client_kwargs=None):
+    def __init__(self, config, client_kwargs=None, till_now=False, log_connection=True):
+        # allow the downloader to specific whether it logs the connection
+        client_kwargs['log_connection'] = log_connection
         super(Downloader, self).__init__(config, client_kwargs)
+
+        # forces the end to be now
+        if till_now:
+            self._end = truncate_datetime(self._now, self._timeframe)
+
         self.download()
 
     def _validate(self):
@@ -25,13 +33,13 @@ class Downloader(ConfigBase):
         routes = self._config.get('routes', {})
         if routes:
             for route, symbols in routes.items():
-                self._logger.info(f'Starting "{route}" download...')
+                self._logger.info(f'Downloading {route} history from "{self._start}" to "{self._end}"...')
                 self.client.get_route(
                     route=route,
                     symbols=symbols,
                     start=self._start,
                     end=self._end,
-                    timeframe=self._config.get('timeframe')
+                    timeframe=self._timeframe
                 )
                 self._logger.info(f'Completed {len(self.client.rest_values)} "{route}" downloads')
                 cached_items += len(self.client.cached_values)
